@@ -265,6 +265,9 @@ class Gitomatic(object):
         return username
 
     def perm_check(self, username, repo, perm):
+        logging.error(username)
+        logging.error(repo)
+        logging.error(perm)
         # Read perm
         real_perm = self.perm_read(repo, username)
 
